@@ -41,7 +41,7 @@ use serde::{Deserialize, Serialize};
 
 /// Endpoint for the DocuSign API.
 /// For production use n4.
-const ENDPOINT: &str = "https://demo.docusign.net/restapi/v2.1/";
+const ENDPOINT: &str = "https://n4.docusign.net/restapi/v2.1/";
 
 /// Entrypoint for interacting with the DocuSign API.
 #[derive(Debug, Clone)]
